#######
History
#######

.. |nark| replace:: ``nark``
.. _nark: https://github.com/hotoffthehamster/nark

.. |hamster-lib| replace:: ``hamster-lib``
.. _hamster-lib: https://github.com/projecthamster/hamster-lib

.. :changelog:

3.0.0a34 (2019-02-22)
=====================

- Hamster Renascence: Total Metempsychosis.

3.0.0.beta.1 (2018-06-09)
=========================

* Rewrite parser. Use more regex. Offload datetime parsing to iso8601.
* Add database migration framework.
  * Include migration from legacy database.

View the :doc:`hamster-lib History <history-hamster-lib>` (pre-fork, pre-|nark|_).

